==> qt-creator-8.0.1.tgz: share/qtcreator/qml/qmlpuppet/qml2puppet/instances/quick3dmaterialnodeinstance.h <==
/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QtGlobal>

#include "quick3drenderablenodeinstance.h"

QT_FORWARD_DECLARE_CLASS(QQuick3DMaterial)

namespace QmlDesigner {
namespace Internal {

class Quick3DMaterialNodeInstance : public Quick3DRenderableNodeInstance
{
public:
    using Pointer = QSharedPointer<Quick3DMaterialNodeInstance>;

    ~Quick3DMaterialNodeInstance() override;
    static Pointer create(QObject *objectToBeWrapped);
    void initialize(const ObjectNodeInstance::Pointer &objectNodeInstance,
                    InstanceContainer::NodeFlags flags) override;

protected:
    explicit Quick3DMaterialNodeInstance(QObject *node);
};

} // namespace Internal
} // namespace QmlDesigner

==> qt-creator-8.0.2p5.tgz: share/qtcreator/qml/qmlpuppet/qml2puppet/instances/quick3dmaterialnodeinstance.h <==
/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QtGlobal>

#include "quick3drenderablenodeinstance.h"

QT_FORWARD_DECLARE_CLASS(QQuick3DMaterial)

namespace QmlDesigner {
namespace Internal {

class Quick3DMaterialNodeInstance : public Quick3DRenderableNodeInstance
{
public:
    using Pointer = QSharedPointer<Quick3DMaterialNodeInstance>;

    ~Quick3DMaterialNodeInstance() override;
    static Pointer create(QObject *objectToBeWrapped);

protected:
    explicit Quick3DMaterialNodeInstance(QObject *node);
    void invokeDummyViewCreate() const override;
};

} // namespace Internal
} // namespace QmlDesigner
